zope.security.simplepolicies — zope.security 4.0dev documentation

### Navigation

- index
- modules |
- next |
- previous |
- zope.security 4.0dev documentation »

# `zope.security.simplepolicies`

Simple ‘ISecurityPolicy’ implementations.

class `zope.security.simplepolicies.` `ParanoidSecurityPolicy`(*participations)

  Bases: `object`

  Prohibit all access exctp to public items, or by explicit principals

class `zope.security.simplepolicies.` `PermissiveSecurityPolicy`(*participations)

  Bases: `zope.security.simplepolicies.ParanoidSecurityPolicy`

  Allow all access.

### Navigation

- index
- modules |
- next |
- previous |
- zope.security 4.0dev documentation »